pub struct CreateCustomerSessionComponentsCustomerSheetFeatures {
pub payment_method_allow_redisplay_filters: Option<Vec<CreateCustomerSessionComponentsCustomerSheetFeaturesPaymentMethodAllowRedisplayFilters>>,
pub payment_method_remove: Option<CreateCustomerSessionComponentsCustomerSheetFeaturesPaymentMethodRemove>,
}Expand description
This hash defines whether the customer sheet supports certain features.
Fields
payment_method_allow_redisplay_filters: Option<Vec<CreateCustomerSessionComponentsCustomerSheetFeaturesPaymentMethodAllowRedisplayFilters>>A list of allow_redisplay values that controls which saved payment methods the customer sheet displays by filtering to only show payment methods with an allow_redisplay value that is present in this list.
If not specified, defaults to [“always”]. In order to display all saved payment methods, specify [“always”, “limited”, “unspecified”].
payment_method_remove: Option<CreateCustomerSessionComponentsCustomerSheetFeaturesPaymentMethodRemove>Controls whether the customer sheet displays the option to remove a saved payment method.“
Allowing buyers to remove their saved payment methods impacts subscriptions that depend on that payment method.
Removing the payment method detaches the customer object from that PaymentMethod.
Implementations