pub struct CapturePaymentIntentAmountDetailsLineItemsPaymentMethodOptions {
pub card: Option<CapturePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsCard>,
pub card_present: Option<CapturePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsCardPresent>,
pub klarna: Option<PaymentIntentAmountDetailsLineItemPaymentMethodOptionsParam>,
pub paypal: Option<CapturePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsPaypal>,
}Expand description
Payment method-specific information for line items.
Fields
card: Option<CapturePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsCard>This sub-hash contains line item details that are specific to the card payment method.
card_present: Option<CapturePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsCardPresent>This sub-hash contains line item details that are specific to the card_present payment method.
klarna: Option<PaymentIntentAmountDetailsLineItemPaymentMethodOptionsParam>This sub-hash contains line item details that are specific to the klarna payment method.
paypal: Option<CapturePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsPaypal>This sub-hash contains line item details that are specific to the paypal payment method.
Implementations