pub struct CapturePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsCard {
pub commodity_code: Option<String>,
}Expand description
This sub-hash contains line item details that are specific to the card payment method.
Fields
commodity_code: Option<String>Identifier that categorizes the items being purchased using a standardized commodity scheme such as (but not limited to) UNSPSC, NAICS, NAPCS, and so on.
Implementations