pub struct CreatePaymentIntentAmountDetailsLineItemsPaymentMethodOptions {
pub card: Option<CreatePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsCard>,
pub card_present: Option<CreatePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsCardPresent>,
pub klarna: Option<PaymentIntentAmountDetailsLineItemPaymentMethodOptionsParam>,
pub paypal: Option<CreatePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsPaypal>,
}Expand description
Payment method-specific information for line items.
Fields
card: Option<CreatePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsCard>This sub-hash contains line item details that are specific to the card payment method.
card_present: Option<CreatePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsCardPresent>This sub-hash contains line item details that are specific to the card_present payment method.
klarna: Option<PaymentIntentAmountDetailsLineItemPaymentMethodOptionsParam>This sub-hash contains line item details that are specific to the klarna payment method.
paypal: Option<CreatePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsPaypal>This sub-hash contains line item details that are specific to the paypal payment method.
Implementations