pub struct UpdatePaymentIntentAmountDetailsLineItemsPaymentMethodOptions {
pub card: Option<UpdatePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsCard>,
pub card_present: Option<UpdatePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsCardPresent>,
pub klarna: Option<PaymentIntentAmountDetailsLineItemPaymentMethodOptionsParam>,
pub paypal: Option<UpdatePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsPaypal>,
}Expand description
Payment method-specific information for line items.
Fields
card: Option<UpdatePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsCard>This sub-hash contains line item details that are specific to the card payment method.
card_present: Option<UpdatePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsCardPresent>This sub-hash contains line item details that are specific to the card_present payment method.
klarna: Option<PaymentIntentAmountDetailsLineItemPaymentMethodOptionsParam>This sub-hash contains line item details that are specific to the klarna payment method.
paypal: Option<UpdatePaymentIntentAmountDetailsLineItemsPaymentMethodOptionsPaypal>This sub-hash contains line item details that are specific to the paypal payment method.
Implementations