pub struct UpdatePaymentIntentPaymentMethodDataRadarOptions {
pub session: Option<String>,
}Expand description
Options to configure Radar. See Radar Session for more information.
Fields
session: Option<String>A Radar Session is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
Implementations