UpdateSetupIntentPaymentMethodOptionsPixMandateOptions

Struct UpdateSetupIntentPaymentMethodOptionsPixMandateOptions 

pub struct UpdateSetupIntentPaymentMethodOptionsPixMandateOptions {
    pub amount: Option<i64>,
    pub amount_includes_iof: Option<UpdateSetupIntentPaymentMethodOptionsPixMandateOptionsAmountIncludesIof>,
    pub amount_type: Option<UpdateSetupIntentPaymentMethodOptionsPixMandateOptionsAmountType>,
    pub currency: Option<Currency>,
    pub end_date: Option<String>,
    pub payment_schedule: Option<UpdateSetupIntentPaymentMethodOptionsPixMandateOptionsPaymentSchedule>,
    pub reference: Option<String>,
    pub start_date: Option<String>,
}
Additional fields for mandate creation.

Fields

amount: Option<i64>

Amount to be charged for future payments. Required when amount_type=fixed. If not provided for amount_type=maximum, defaults to 40000.

amount_includes_iof: Option<UpdateSetupIntentPaymentMethodOptionsPixMandateOptionsAmountIncludesIof>

Determines if the amount includes the IOF tax. Defaults to never.

amount_type: Option<UpdateSetupIntentPaymentMethodOptionsPixMandateOptionsAmountType>

Type of amount. Defaults to maximum.

currency: Option<Currency>

Three-letter ISO currency code, in lowercase. Only brl is supported currently.

end_date: Option<String>

Date when the mandate expires and no further payments will be charged, in YYYY-MM-DD. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.

payment_schedule: Option<UpdateSetupIntentPaymentMethodOptionsPixMandateOptionsPaymentSchedule>

Schedule at which the future payments will be charged. Defaults to monthly.

reference: Option<String>

Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.

start_date: Option<String>

Start date of the mandate, in YYYY-MM-DD. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.

Implementations