pub struct ConnectCollectionTransfer {
pub amount: i64,
pub currency: Currency,
pub destination: Expandable<Account>,
pub id: ConnectCollectionTransferId,
pub livemode: bool,
}Fields
amount: i64Amount transferred, in cents (or local equivalent).
currency: CurrencyThree-letter ISO currency code, in lowercase. Must be a supported currency.
destination: Expandable<Account>ID of the account that funds are being collected for.
id: ConnectCollectionTransferIdUnique identifier for the object.
livemode: boolIf the object exists in live mode, the value is true.
If the object exists in test mode, the value is false.