CustomerSessionResourceComponentsResourceCustomerSheetResourceFeatures

Struct CustomerSessionResourceComponentsResourceCustomerSheetResourceFeatures 

pub struct CustomerSessionResourceComponentsResourceCustomerSheetResourceFeatures {
    pub payment_method_allow_redisplay_filters: Option<Vec<CustomerSessionResourceComponentsResourceCustomerSheetResourceFeaturesPaymentMethodAllowRedisplayFilters>>,
    pub payment_method_remove: Option<CustomerSessionResourceComponentsResourceCustomerSheetResourceFeaturesPaymentMethodRemove>,
}
This hash contains the features the customer sheet supports.

Fields

payment_method_allow_redisplay_filters: Option<Vec<CustomerSessionResourceComponentsResourceCustomerSheetResourceFeaturesPaymentMethodAllowRedisplayFilters>>

A list of allow_redisplay values that controls which saved payment methods the customer sheet displays by filtering to only show payment methods with an allow_redisplay value that is present in this list.

If not specified, defaults to [“always”]. In order to display all saved payment methods, specify [“always”, “limited”, “unspecified”].

payment_method_remove: Option<CustomerSessionResourceComponentsResourceCustomerSheetResourceFeaturesPaymentMethodRemove>

Controls whether the customer sheet displays the option to remove a saved payment method.“

Allowing buyers to remove their saved payment methods impacts subscriptions that depend on that payment method. Removing the payment method detaches the customer object from that PaymentMethod.