NotificationEventRequest

Struct NotificationEventRequest 

pub struct NotificationEventRequest {
    pub id: Option<String>,
    pub idempotency_key: Option<String>,
}

Fields

id: Option<String>

ID of the API request that caused the event. If null, the event was automatic (e.g., Stripe’s automatic subscription handling). Request logs are available in the dashboard, but currently not in the API.

idempotency_key: Option<String>

The idempotency key transmitted during the request, if any. Note: This property is populated only for events on or after May 23, 2017.