PaymentFlowsAutomaticPaymentMethodsSetupIntent

Struct PaymentFlowsAutomaticPaymentMethodsSetupIntent 

pub struct PaymentFlowsAutomaticPaymentMethodsSetupIntent {
    pub allow_redirects: Option<PaymentFlowsAutomaticPaymentMethodsSetupIntentAllowRedirects>,
    pub enabled: Option<bool>,
}

Fields

allow_redirects: Option<PaymentFlowsAutomaticPaymentMethodsSetupIntentAllowRedirects>

Controls whether this SetupIntent will accept redirect-based payment methods.

Redirect-based payment methods may require your customer to be redirected to a payment method’s app or site for authentication or additional steps. To confirm this SetupIntent, you may be required to provide a return_url to redirect customers back to your site after they authenticate or complete the setup.

enabled: Option<bool>

Automatically calculates compatible payment methods