pub struct PaymentIntentNextActionUpiHandleRedirectOrDisplayQrCode {
pub hosted_instructions_url: String,
pub qr_code: PaymentIntentNextActionUpiqrCode,
}Fields
hosted_instructions_url: StringThe URL to the hosted UPI instructions page, which allows customers to view the QR code.
qr_code: PaymentIntentNextActionUpiqrCodeTrait Implementations
Sourceimpl Clone for PaymentIntentNextActionUpiHandleRedirectOrDisplayQrCode
impl Clone for PaymentIntentNextActionUpiHandleRedirectOrDisplayQrCode
Sourcefn clone(&self) -> PaymentIntentNextActionUpiHandleRedirectOrDisplayQrCode
fn clone(&self) -> PaymentIntentNextActionUpiHandleRedirectOrDisplayQrCode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for PaymentIntentNextActionUpiHandleRedirectOrDisplayQrCode
impl PartialEq for PaymentIntentNextActionUpiHandleRedirectOrDisplayQrCode
Sourcefn eq(
&self,
other: &PaymentIntentNextActionUpiHandleRedirectOrDisplayQrCode,
) -> bool
fn eq( &self, other: &PaymentIntentNextActionUpiHandleRedirectOrDisplayQrCode, ) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for PaymentIntentNextActionUpiHandleRedirectOrDisplayQrCode
impl StructuralPartialEq for PaymentIntentNextActionUpiHandleRedirectOrDisplayQrCode