SetupIntentNextActionPixDisplayQrCode

Struct SetupIntentNextActionPixDisplayQrCode 

pub struct SetupIntentNextActionPixDisplayQrCode {
    pub data: String,
    pub expires_at: i64,
    pub hosted_instructions_url: String,
    pub image_url_png: String,
    pub image_url_svg: String,
}

Fields

data: String

The raw data string used to generate QR code, it should be used together with QR code library.

expires_at: i64

The date (unix timestamp) when the PIX expires.

hosted_instructions_url: String

The URL to the hosted pix instructions page, which allows customers to view the pix QR code.

image_url_png: String

The image_url_png string used to render png QR code

image_url_svg: String

The image_url_svg string used to render svg QR code