pub struct CreateTokenAccountCompanyRepresentativeDeclaration {
pub date: Option<Timestamp>,
pub ip: Option<String>,
pub user_agent: Option<String>,
}Expand description
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
Fields
date: Option<Timestamp>The Unix timestamp marking when the representative declaration attestation was made.
ip: Option<String>The IP address from which the representative declaration attestation was made.
user_agent: Option<String>The user agent of the browser from which the representative declaration attestation was made.
Implementations