pub struct CreatePaymentIntentAmountDetails {
pub discount_amount: Option<i64>,
pub enforce_arithmetic_validation: Option<bool>,
pub line_items: Option<Vec<CreatePaymentIntentAmountDetailsLineItems>>,
pub shipping: Option<AmountDetailsShippingParam>,
pub tax: Option<AmountDetailsTaxParam>,
}Expand description
Provides industry-specific information about the amount.
Fields
discount_amount: Option<i64>The total discount applied on the transaction represented in the smallest currency unit. An integer greater than 0.
This field is mutually exclusive with the amount_details[line_items][#][discount_amount] field.
enforce_arithmetic_validation: Option<bool>Set to false to return arithmetic validation errors in the response without failing the request.
Use this when you want the operation to proceed regardless of arithmetic errors in the line item data.
Omit or set to true to immediately return a 400 error when arithmetic validation fails.
Use this for strict validation that prevents processing with line item data that has arithmetic inconsistencies.
For card payments, Stripe doesn’t send line item data to card networks if there’s an arithmetic validation error.
line_items: Option<Vec<CreatePaymentIntentAmountDetailsLineItems>>A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 200 line items.
shipping: Option<AmountDetailsShippingParam>Contains information about the shipping portion of the amount.
tax: Option<AmountDetailsTaxParam>Contains information about the tax portion of the amount.
Implementations