pub struct SetupIntentNextActionPixDisplayQrCode {
pub data: String,
pub expires_at: i64,
pub hosted_instructions_url: String,
pub image_url_png: String,
pub image_url_svg: String,
}Fields
data: StringThe raw data string used to generate QR code, it should be used together with QR code library.
expires_at: i64The date (unix timestamp) when the PIX expires.
hosted_instructions_url: StringThe URL to the hosted pix instructions page, which allows customers to view the pix QR code.
image_url_png: StringThe image_url_png string used to render png QR code
image_url_svg: StringThe image_url_svg string used to render svg QR code